@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.vision_v1.services.product_search import pagers
@@ -194,12 +196,12 @@ class ProductSearchAsyncClient:
 
     async def create_product_set(
         self,
-        request: product_search_service.CreateProductSetRequest = None,
+        request: Union[product_search_service.CreateProductSetRequest, dict] = None,
         *,
         parent: str = None,
         product_set: product_search_service.ProductSet = None,
         product_set_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -211,7 +213,7 @@ class ProductSearchAsyncClient:
            longer than 4096 characters.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.CreateProductSetRequest`):
+            request (Union[google.cloud.vision_v1.types.CreateProductSetRequest, dict]):
                 The request object. Request message for the
                 `CreateProductSet` method.
             parent (:class:`str`):
@@ -303,10 +305,10 @@ class ProductSearchAsyncClient:
 
     async def list_product_sets(
         self,
-        request: product_search_service.ListProductSetsRequest = None,
+        request: Union[product_search_service.ListProductSetsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductSetsAsyncPager:
@@ -318,7 +320,7 @@ class ProductSearchAsyncClient:
            less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.ListProductSetsRequest`):
+            request (Union[google.cloud.vision_v1.types.ListProductSetsRequest, dict]):
                 The request object. Request message for the
                 `ListProductSets` method.
             parent (:class:`str`):
@@ -399,10 +401,10 @@ class ProductSearchAsyncClient:
 
     async def get_product_set(
         self,
-        request: product_search_service.GetProductSetRequest = None,
+        request: Union[product_search_service.GetProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -413,7 +415,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the ProductSet does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.GetProductSetRequest`):
+            request (Union[google.cloud.vision_v1.types.GetProductSetRequest, dict]):
                 The request object. Request message for the
                 `GetProductSet` method.
             name (:class:`str`):
@@ -489,11 +491,11 @@ class ProductSearchAsyncClient:
 
     async def update_product_set(
         self,
-        request: product_search_service.UpdateProductSetRequest = None,
+        request: Union[product_search_service.UpdateProductSetRequest, dict] = None,
         *,
         product_set: product_search_service.ProductSet = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -508,7 +510,7 @@ class ProductSearchAsyncClient:
            characters.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.UpdateProductSetRequest`):
+            request (Union[google.cloud.vision_v1.types.UpdateProductSetRequest, dict]):
                 The request object. Request message for the
                 `UpdateProductSet` method.
             product_set (:class:`google.cloud.vision_v1.types.ProductSet`):
@@ -595,10 +597,10 @@ class ProductSearchAsyncClient:
 
     async def delete_product_set(
         self,
-        request: product_search_service.DeleteProductSetRequest = None,
+        request: Union[product_search_service.DeleteProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -608,7 +610,7 @@ class ProductSearchAsyncClient:
         Storage.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.DeleteProductSetRequest`):
+            request (Union[google.cloud.vision_v1.types.DeleteProductSetRequest, dict]):
                 The request object. Request message for the
                 `DeleteProductSet` method.
             name (:class:`str`):
@@ -674,12 +676,12 @@ class ProductSearchAsyncClient:
 
     async def create_product(
         self,
-        request: product_search_service.CreateProductRequest = None,
+        request: Union[product_search_service.CreateProductRequest, dict] = None,
         *,
         parent: str = None,
         product: product_search_service.Product = None,
         product_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -695,7 +697,7 @@ class ProductSearchAsyncClient:
            invalid.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.CreateProductRequest`):
+            request (Union[google.cloud.vision_v1.types.CreateProductRequest, dict]):
                 The request object. Request message for the
                 `CreateProduct` method.
             parent (:class:`str`):
@@ -782,10 +784,10 @@ class ProductSearchAsyncClient:
 
     async def list_products(
         self,
-        request: product_search_service.ListProductsRequest = None,
+        request: Union[product_search_service.ListProductsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsAsyncPager:
@@ -797,7 +799,7 @@ class ProductSearchAsyncClient:
            less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.ListProductsRequest`):
+            request (Union[google.cloud.vision_v1.types.ListProductsRequest, dict]):
                 The request object. Request message for the
                 `ListProducts` method.
             parent (:class:`str`):
@@ -878,10 +880,10 @@ class ProductSearchAsyncClient:
 
     async def get_product(
         self,
-        request: product_search_service.GetProductRequest = None,
+        request: Union[product_search_service.GetProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -892,7 +894,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the Product does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.GetProductRequest`):
+            request (Union[google.cloud.vision_v1.types.GetProductRequest, dict]):
                 The request object. Request message for the `GetProduct`
                 method.
             name (:class:`str`):
@@ -963,11 +965,11 @@ class ProductSearchAsyncClient:
 
     async def update_product(
         self,
-        request: product_search_service.UpdateProductRequest = None,
+        request: Union[product_search_service.UpdateProductRequest, dict] = None,
         *,
         product: product_search_service.Product = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -989,7 +991,7 @@ class ProductSearchAsyncClient:
            update_mask.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.UpdateProductRequest`):
+            request (Union[google.cloud.vision_v1.types.UpdateProductRequest, dict]):
                 The request object. Request message for the
                 `UpdateProduct` method.
             product (:class:`google.cloud.vision_v1.types.Product`):
@@ -1073,10 +1075,10 @@ class ProductSearchAsyncClient:
 
     async def delete_product(
         self,
-        request: product_search_service.DeleteProductRequest = None,
+        request: Union[product_search_service.DeleteProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1088,7 +1090,7 @@ class ProductSearchAsyncClient:
         all related caches are refreshed.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.DeleteProductRequest`):
+            request (Union[google.cloud.vision_v1.types.DeleteProductRequest, dict]):
                 The request object. Request message for the
                 `DeleteProduct` method.
             name (:class:`str`):
@@ -1154,12 +1156,12 @@ class ProductSearchAsyncClient:
 
     async def create_reference_image(
         self,
-        request: product_search_service.CreateReferenceImageRequest = None,
+        request: Union[product_search_service.CreateReferenceImageRequest, dict] = None,
         *,
         parent: str = None,
         reference_image: product_search_service.ReferenceImage = None,
         reference_image_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1187,7 +1189,7 @@ class ProductSearchAsyncClient:
            10 polygons.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.CreateReferenceImageRequest`):
+            request (Union[google.cloud.vision_v1.types.CreateReferenceImageRequest, dict]):
                 The request object. Request message for the
                 `CreateReferenceImage` method.
             parent (:class:`str`):
@@ -1280,10 +1282,10 @@ class ProductSearchAsyncClient:
 
     async def delete_reference_image(
         self,
-        request: product_search_service.DeleteReferenceImageRequest = None,
+        request: Union[product_search_service.DeleteReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1296,7 +1298,7 @@ class ProductSearchAsyncClient:
         Storage.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.DeleteReferenceImageRequest`):
+            request (Union[google.cloud.vision_v1.types.DeleteReferenceImageRequest, dict]):
                 The request object. Request message for the
                 `DeleteReferenceImage` method.
             name (:class:`str`):
@@ -1363,10 +1365,10 @@ class ProductSearchAsyncClient:
 
     async def list_reference_images(
         self,
-        request: product_search_service.ListReferenceImagesRequest = None,
+        request: Union[product_search_service.ListReferenceImagesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReferenceImagesAsyncPager:
@@ -1379,7 +1381,7 @@ class ProductSearchAsyncClient:
            100, or less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.ListReferenceImagesRequest`):
+            request (Union[google.cloud.vision_v1.types.ListReferenceImagesRequest, dict]):
                 The request object. Request message for the
                 `ListReferenceImages` method.
             parent (:class:`str`):
@@ -1461,10 +1463,10 @@ class ProductSearchAsyncClient:
 
     async def get_reference_image(
         self,
-        request: product_search_service.GetReferenceImageRequest = None,
+        request: Union[product_search_service.GetReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1475,7 +1477,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the specified image does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.GetReferenceImageRequest`):
+            request (Union[google.cloud.vision_v1.types.GetReferenceImageRequest, dict]):
                 The request object. Request message for the
                 `GetReferenceImage` method.
             name (:class:`str`):
@@ -1549,11 +1551,13 @@ class ProductSearchAsyncClient:
 
     async def add_product_to_product_set(
         self,
-        request: product_search_service.AddProductToProductSetRequest = None,
+        request: Union[
+            product_search_service.AddProductToProductSetRequest, dict
+        ] = None,
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1568,7 +1572,7 @@ class ProductSearchAsyncClient:
            exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.AddProductToProductSetRequest`):
+            request (Union[google.cloud.vision_v1.types.AddProductToProductSetRequest, dict]):
                 The request object. Request message for the
                 `AddProductToProductSet` method.
             name (:class:`str`):
@@ -1647,18 +1651,20 @@ class ProductSearchAsyncClient:
 
     async def remove_product_from_product_set(
         self,
-        request: product_search_service.RemoveProductFromProductSetRequest = None,
+        request: Union[
+            product_search_service.RemoveProductFromProductSetRequest, dict
+        ] = None,
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Removes a Product from the specified ProductSet.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.RemoveProductFromProductSetRequest`):
+            request (Union[google.cloud.vision_v1.types.RemoveProductFromProductSetRequest, dict]):
                 The request object. Request message for the
                 `RemoveProductFromProductSet` method.
             name (:class:`str`):
@@ -1737,10 +1743,12 @@ class ProductSearchAsyncClient:
 
     async def list_products_in_product_set(
         self,
-        request: product_search_service.ListProductsInProductSetRequest = None,
+        request: Union[
+            product_search_service.ListProductsInProductSetRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsInProductSetAsyncPager:
@@ -1754,7 +1762,7 @@ class ProductSearchAsyncClient:
            less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.ListProductsInProductSetRequest`):
+            request (Union[google.cloud.vision_v1.types.ListProductsInProductSetRequest, dict]):
                 The request object. Request message for the
                 `ListProductsInProductSet` method.
             name (:class:`str`):
@@ -1837,11 +1845,11 @@ class ProductSearchAsyncClient:
 
     async def import_product_sets(
         self,
-        request: product_search_service.ImportProductSetsRequest = None,
+        request: Union[product_search_service.ImportProductSetsRequest, dict] = None,
         *,
         parent: str = None,
         input_config: product_search_service.ImportProductSetsInputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1859,7 +1867,7 @@ class ProductSearchAsyncClient:
         [ImportProductSetsGcsSource.csv_file_uri][google.cloud.vision.v1.ImportProductSetsGcsSource.csv_file_uri].
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.ImportProductSetsRequest`):
+            request (Union[google.cloud.vision_v1.types.ImportProductSetsRequest, dict]):
                 The request object. Request message for the
                 `ImportProductSets` method.
             parent (:class:`str`):
@@ -1955,10 +1963,10 @@ class ProductSearchAsyncClient:
 
     async def purge_products(
         self,
-        request: product_search_service.PurgeProductsRequest = None,
+        request: Union[product_search_service.PurgeProductsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1991,7 +1999,7 @@ class ProductSearchAsyncClient:
         ``BatchOperationMetadata``. (progress)
 
         Args:
-            request (:class:`google.cloud.vision_v1.types.PurgeProductsRequest`):
+            request (Union[google.cloud.vision_v1.types.PurgeProductsRequest, dict]):
                 The request object. Request message for the
                 `PurgeProducts` method.
             parent (:class:`str`):
