@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.vision_v1.services.product_search import pagers
@@ -414,7 +416,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         parent: str = None,
         product_set: product_search_service.ProductSet = None,
         product_set_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -514,7 +516,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.ListProductSetsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductSetsPager:
@@ -600,7 +602,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.GetProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -681,7 +683,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         product_set: product_search_service.ProductSet = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -776,7 +778,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.DeleteProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -847,7 +849,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         parent: str = None,
         product: product_search_service.Product = None,
         product_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -946,7 +948,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.ListProductsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsPager:
@@ -1032,7 +1034,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.GetProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -1108,7 +1110,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         product: product_search_service.Product = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -1207,7 +1209,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.DeleteProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1280,7 +1282,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         parent: str = None,
         reference_image: product_search_service.ReferenceImage = None,
         reference_image_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1397,7 +1399,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.DeleteReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1470,7 +1472,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.ListReferenceImagesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReferenceImagesPager:
@@ -1558,7 +1560,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.GetReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1639,7 +1641,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1733,7 +1735,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1818,7 +1820,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsInProductSetPager:
@@ -1913,7 +1915,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         parent: str = None,
         input_config: product_search_service.ImportProductSetsInputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -2023,7 +2025,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.PurgeProductsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
