@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.vision_v1p1beta1.types import image_annotator
 from .transports.base import ImageAnnotatorTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import ImageAnnotatorGrpcAsyncIOTransport
@@ -164,10 +166,10 @@ class ImageAnnotatorAsyncClient:
 
     async def batch_annotate_images(
         self,
-        request: image_annotator.BatchAnnotateImagesRequest = None,
+        request: Union[image_annotator.BatchAnnotateImagesRequest, dict] = None,
         *,
         requests: Sequence[image_annotator.AnnotateImageRequest] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> image_annotator.BatchAnnotateImagesResponse:
@@ -175,7 +177,7 @@ class ImageAnnotatorAsyncClient:
         images.
 
         Args:
-            request (:class:`google.cloud.vision_v1p1beta1.types.BatchAnnotateImagesRequest`):
+            request (Union[google.cloud.vision_v1p1beta1.types.BatchAnnotateImagesRequest, dict]):
                 The request object. Multiple image annotation requests
                 are batched into a single service call.
             requests (:class:`Sequence[google.cloud.vision_v1p1beta1.types.AnnotateImageRequest]`):
