@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,16 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.vision_v1p1beta1.types import geometry
 from google.cloud.vision_v1p1beta1.types import text_annotation
 from google.cloud.vision_v1p1beta1.types import web_detection as gcv_web_detection
-from google.rpc import status_pb2 as status  # type: ignore
-from google.type import color_pb2 as gt_color  # type: ignore
-from google.type import latlng_pb2 as latlng  # type: ignore
+from google.rpc import status_pb2  # type: ignore
+from google.type import color_pb2  # type: ignore
+from google.type import latlng_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -76,7 +73,7 @@ class Feature(proto.Message):
     return.
 
     Attributes:
-        type_ (~.image_annotator.Feature.Type):
+        type_ (google.cloud.vision_v1p1beta1.types.Feature.Type):
             The feature type.
         max_results (int):
             Maximum number of results of this type.
@@ -101,10 +98,8 @@ class Feature(proto.Message):
         WEB_DETECTION = 10
 
     type_ = proto.Field(proto.ENUM, number=1, enum=Type,)
-
-    max_results = proto.Field(proto.INT32, number=2)
-
-    model = proto.Field(proto.STRING, number=3)
+    max_results = proto.Field(proto.INT32, number=2,)
+    model = proto.Field(proto.STRING, number=3,)
 
 
 class ImageSource(proto.Message):
@@ -132,9 +127,8 @@ class ImageSource(proto.Message):
                ``image_uri`` takes precedence.
     """
 
-    gcs_image_uri = proto.Field(proto.STRING, number=1)
-
-    image_uri = proto.Field(proto.STRING, number=2)
+    gcs_image_uri = proto.Field(proto.STRING, number=1,)
+    image_uri = proto.Field(proto.STRING, number=2,)
 
 
 class Image(proto.Message):
@@ -145,15 +139,14 @@ class Image(proto.Message):
             Image content, represented as a stream of bytes. Note: as
             with all ``bytes`` fields, protobuffers use a pure binary
             representation, whereas JSON representations use base64.
-        source (~.image_annotator.ImageSource):
+        source (google.cloud.vision_v1p1beta1.types.ImageSource):
             Google Cloud Storage image location. If both ``content`` and
             ``source`` are provided for an image, ``content`` takes
             precedence and is used to perform the image annotation
             request.
     """
 
-    content = proto.Field(proto.BYTES, number=1)
-
+    content = proto.Field(proto.BYTES, number=1,)
     source = proto.Field(proto.MESSAGE, number=2, message="ImageSource",)
 
 
@@ -162,7 +155,7 @@ class FaceAnnotation(proto.Message):
     detection.
 
     Attributes:
-        bounding_poly (~.geometry.BoundingPoly):
+        bounding_poly (google.cloud.vision_v1p1beta1.types.BoundingPoly):
             The bounding polygon around the face. The coordinates of the
             bounding box are in the original image's scale, as returned
             in ``ImageParams``. The bounding box is computed to "frame"
@@ -171,7 +164,7 @@ class FaceAnnotation(proto.Message):
             coordinates may not be generated in the ``BoundingPoly``
             (the polygon will be unbounded) if only a partial face
             appears in the image to be annotated.
-        fd_bounding_poly (~.geometry.BoundingPoly):
+        fd_bounding_poly (google.cloud.vision_v1p1beta1.types.BoundingPoly):
             The ``fd_bounding_poly`` bounding polygon is tighter than
             the ``boundingPoly``, and encloses only the skin part of the
             face. Typically, it is used to eliminate the face from any
@@ -179,7 +172,7 @@ class FaceAnnotation(proto.Message):
             an image. It is not based on the landmarker results, only on
             the initial face detection, hence the fd (face detection)
             prefix.
-        landmarks (Sequence[~.image_annotator.FaceAnnotation.Landmark]):
+        landmarks (Sequence[google.cloud.vision_v1p1beta1.types.FaceAnnotation.Landmark]):
             Detected face landmarks.
         roll_angle (float):
             Roll angle, which indicates the amount of
@@ -198,19 +191,19 @@ class FaceAnnotation(proto.Message):
             Detection confidence. Range [0, 1].
         landmarking_confidence (float):
             Face landmarking confidence. Range [0, 1].
-        joy_likelihood (~.image_annotator.Likelihood):
+        joy_likelihood (google.cloud.vision_v1p1beta1.types.Likelihood):
             Joy likelihood.
-        sorrow_likelihood (~.image_annotator.Likelihood):
+        sorrow_likelihood (google.cloud.vision_v1p1beta1.types.Likelihood):
             Sorrow likelihood.
-        anger_likelihood (~.image_annotator.Likelihood):
+        anger_likelihood (google.cloud.vision_v1p1beta1.types.Likelihood):
             Anger likelihood.
-        surprise_likelihood (~.image_annotator.Likelihood):
+        surprise_likelihood (google.cloud.vision_v1p1beta1.types.Likelihood):
             Surprise likelihood.
-        under_exposed_likelihood (~.image_annotator.Likelihood):
+        under_exposed_likelihood (google.cloud.vision_v1p1beta1.types.Likelihood):
             Under-exposed likelihood.
-        blurred_likelihood (~.image_annotator.Likelihood):
+        blurred_likelihood (google.cloud.vision_v1p1beta1.types.Likelihood):
             Blurred likelihood.
-        headwear_likelihood (~.image_annotator.Likelihood):
+        headwear_likelihood (google.cloud.vision_v1p1beta1.types.Likelihood):
             Headwear likelihood.
     """
 
@@ -218,9 +211,9 @@ class FaceAnnotation(proto.Message):
         r"""A face-specific landmark (for example, a face feature).
 
         Attributes:
-            type_ (~.image_annotator.FaceAnnotation.Landmark.Type):
+            type_ (google.cloud.vision_v1p1beta1.types.FaceAnnotation.Landmark.Type):
                 Face landmark type.
-            position (~.geometry.Position):
+            position (google.cloud.vision_v1p1beta1.types.Position):
                 Face landmark position.
         """
 
@@ -267,39 +260,24 @@ class FaceAnnotation(proto.Message):
             CHIN_RIGHT_GONION = 34
 
         type_ = proto.Field(proto.ENUM, number=3, enum="FaceAnnotation.Landmark.Type",)
-
         position = proto.Field(proto.MESSAGE, number=4, message=geometry.Position,)
 
     bounding_poly = proto.Field(proto.MESSAGE, number=1, message=geometry.BoundingPoly,)
-
     fd_bounding_poly = proto.Field(
         proto.MESSAGE, number=2, message=geometry.BoundingPoly,
     )
-
     landmarks = proto.RepeatedField(proto.MESSAGE, number=3, message=Landmark,)
-
-    roll_angle = proto.Field(proto.FLOAT, number=4)
-
-    pan_angle = proto.Field(proto.FLOAT, number=5)
-
-    tilt_angle = proto.Field(proto.FLOAT, number=6)
-
-    detection_confidence = proto.Field(proto.FLOAT, number=7)
-
-    landmarking_confidence = proto.Field(proto.FLOAT, number=8)
-
+    roll_angle = proto.Field(proto.FLOAT, number=4,)
+    pan_angle = proto.Field(proto.FLOAT, number=5,)
+    tilt_angle = proto.Field(proto.FLOAT, number=6,)
+    detection_confidence = proto.Field(proto.FLOAT, number=7,)
+    landmarking_confidence = proto.Field(proto.FLOAT, number=8,)
     joy_likelihood = proto.Field(proto.ENUM, number=9, enum="Likelihood",)
-
     sorrow_likelihood = proto.Field(proto.ENUM, number=10, enum="Likelihood",)
-
     anger_likelihood = proto.Field(proto.ENUM, number=11, enum="Likelihood",)
-
     surprise_likelihood = proto.Field(proto.ENUM, number=12, enum="Likelihood",)
-
     under_exposed_likelihood = proto.Field(proto.ENUM, number=13, enum="Likelihood",)
-
     blurred_likelihood = proto.Field(proto.ENUM, number=14, enum="Likelihood",)
-
     headwear_likelihood = proto.Field(proto.ENUM, number=15, enum="Likelihood",)
 
 
@@ -307,11 +285,11 @@ class LocationInfo(proto.Message):
     r"""Detected entity location information.
 
     Attributes:
-        lat_lng (~.latlng.LatLng):
+        lat_lng (google.type.latlng_pb2.LatLng):
             lat/long location coordinates.
     """
 
-    lat_lng = proto.Field(proto.MESSAGE, number=1, message=latlng.LatLng,)
+    lat_lng = proto.Field(proto.MESSAGE, number=1, message=latlng_pb2.LatLng,)
 
 
 class Property(proto.Message):
@@ -326,11 +304,9 @@ class Property(proto.Message):
             Value of numeric properties.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    value = proto.Field(proto.STRING, number=2)
-
-    uint64_value = proto.Field(proto.UINT64, number=3)
+    name = proto.Field(proto.STRING, number=1,)
+    value = proto.Field(proto.STRING, number=2,)
+    uint64_value = proto.Field(proto.UINT64, number=3,)
 
 
 class EntityAnnotation(proto.Message):
@@ -361,38 +337,30 @@ class EntityAnnotation(proto.Message):
             than to an image containing a detected distant towering
             building, even though the confidence that there is a tower
             in each image may be the same. Range [0, 1].
-        bounding_poly (~.geometry.BoundingPoly):
+        bounding_poly (google.cloud.vision_v1p1beta1.types.BoundingPoly):
             Image region to which this entity belongs. Not produced for
             ``LABEL_DETECTION`` features.
-        locations (Sequence[~.image_annotator.LocationInfo]):
+        locations (Sequence[google.cloud.vision_v1p1beta1.types.LocationInfo]):
             The location information for the detected entity. Multiple
             ``LocationInfo`` elements can be present because one
             location may indicate the location of the scene in the
             image, and another location may indicate the location of the
             place where the image was taken. Location information is
             usually present for landmarks.
-        properties (Sequence[~.image_annotator.Property]):
+        properties (Sequence[google.cloud.vision_v1p1beta1.types.Property]):
             Some entities may have optional user-supplied ``Property``
             (name/value) fields, such a score or string that qualifies
             the entity.
     """
 
-    mid = proto.Field(proto.STRING, number=1)
-
-    locale = proto.Field(proto.STRING, number=2)
-
-    description = proto.Field(proto.STRING, number=3)
-
-    score = proto.Field(proto.FLOAT, number=4)
-
-    confidence = proto.Field(proto.FLOAT, number=5)
-
-    topicality = proto.Field(proto.FLOAT, number=6)
-
+    mid = proto.Field(proto.STRING, number=1,)
+    locale = proto.Field(proto.STRING, number=2,)
+    description = proto.Field(proto.STRING, number=3,)
+    score = proto.Field(proto.FLOAT, number=4,)
+    confidence = proto.Field(proto.FLOAT, number=5,)
+    topicality = proto.Field(proto.FLOAT, number=6,)
     bounding_poly = proto.Field(proto.MESSAGE, number=7, message=geometry.BoundingPoly,)
-
     locations = proto.RepeatedField(proto.MESSAGE, number=8, message="LocationInfo",)
-
     properties = proto.RepeatedField(proto.MESSAGE, number=9, message="Property",)
 
 
@@ -402,21 +370,21 @@ class SafeSearchAnnotation(proto.Message):
     spoof, medical, violence).
 
     Attributes:
-        adult (~.image_annotator.Likelihood):
+        adult (google.cloud.vision_v1p1beta1.types.Likelihood):
             Represents the adult content likelihood for
             the image. Adult content may contain elements
             such as nudity, pornographic images or cartoons,
             or sexual activities.
-        spoof (~.image_annotator.Likelihood):
+        spoof (google.cloud.vision_v1p1beta1.types.Likelihood):
             Spoof likelihood. The likelihood that an
             modification was made to the image's canonical
             version to make it appear funny or offensive.
-        medical (~.image_annotator.Likelihood):
+        medical (google.cloud.vision_v1p1beta1.types.Likelihood):
             Likelihood that this is a medical image.
-        violence (~.image_annotator.Likelihood):
+        violence (google.cloud.vision_v1p1beta1.types.Likelihood):
             Likelihood that this image contains violent
             content.
-        racy (~.image_annotator.Likelihood):
+        racy (google.cloud.vision_v1p1beta1.types.Likelihood):
             Likelihood that the request image contains
             racy content. Racy content may include (but is
             not limited to) skimpy or sheer clothing,
@@ -426,13 +394,9 @@ class SafeSearchAnnotation(proto.Message):
     """
 
     adult = proto.Field(proto.ENUM, number=1, enum="Likelihood",)
-
     spoof = proto.Field(proto.ENUM, number=2, enum="Likelihood",)
-
     medical = proto.Field(proto.ENUM, number=3, enum="Likelihood",)
-
     violence = proto.Field(proto.ENUM, number=4, enum="Likelihood",)
-
     racy = proto.Field(proto.ENUM, number=9, enum="Likelihood",)
 
 
@@ -440,15 +404,14 @@ class LatLongRect(proto.Message):
     r"""Rectangle determined by min and max ``LatLng`` pairs.
 
     Attributes:
-        min_lat_lng (~.latlng.LatLng):
+        min_lat_lng (google.type.latlng_pb2.LatLng):
             Min lat/long pair.
-        max_lat_lng (~.latlng.LatLng):
+        max_lat_lng (google.type.latlng_pb2.LatLng):
             Max lat/long pair.
     """
 
-    min_lat_lng = proto.Field(proto.MESSAGE, number=1, message=latlng.LatLng,)
-
-    max_lat_lng = proto.Field(proto.MESSAGE, number=2, message=latlng.LatLng,)
+    min_lat_lng = proto.Field(proto.MESSAGE, number=1, message=latlng_pb2.LatLng,)
+    max_lat_lng = proto.Field(proto.MESSAGE, number=2, message=latlng_pb2.LatLng,)
 
 
 class ColorInfo(proto.Message):
@@ -456,7 +419,7 @@ class ColorInfo(proto.Message):
     fraction of the image that the color occupies in the image.
 
     Attributes:
-        color (~.gt_color.Color):
+        color (google.type.color_pb2.Color):
             RGB components of the color.
         score (float):
             Image-specific score for this color. Value in range [0, 1].
@@ -465,18 +428,16 @@ class ColorInfo(proto.Message):
             Value in range [0, 1].
     """
 
-    color = proto.Field(proto.MESSAGE, number=1, message=gt_color.Color,)
-
-    score = proto.Field(proto.FLOAT, number=2)
-
-    pixel_fraction = proto.Field(proto.FLOAT, number=3)
+    color = proto.Field(proto.MESSAGE, number=1, message=color_pb2.Color,)
+    score = proto.Field(proto.FLOAT, number=2,)
+    pixel_fraction = proto.Field(proto.FLOAT, number=3,)
 
 
 class DominantColorsAnnotation(proto.Message):
     r"""Set of dominant colors and their corresponding scores.
 
     Attributes:
-        colors (Sequence[~.image_annotator.ColorInfo]):
+        colors (Sequence[google.cloud.vision_v1p1beta1.types.ColorInfo]):
             RGB color values with their score and pixel
             fraction.
     """
@@ -488,7 +449,7 @@ class ImageProperties(proto.Message):
     r"""Stores image properties, such as dominant colors.
 
     Attributes:
-        dominant_colors (~.image_annotator.DominantColorsAnnotation):
+        dominant_colors (google.cloud.vision_v1p1beta1.types.DominantColorsAnnotation):
             If present, dominant colors completed
             successfully.
     """
@@ -503,7 +464,7 @@ class CropHint(proto.Message):
     serving an image.
 
     Attributes:
-        bounding_poly (~.geometry.BoundingPoly):
+        bounding_poly (google.cloud.vision_v1p1beta1.types.BoundingPoly):
             The bounding polygon for the crop region. The coordinates of
             the bounding box are in the original image's scale, as
             returned in ``ImageParams``.
@@ -515,10 +476,8 @@ class CropHint(proto.Message):
     """
 
     bounding_poly = proto.Field(proto.MESSAGE, number=1, message=geometry.BoundingPoly,)
-
-    confidence = proto.Field(proto.FLOAT, number=2)
-
-    importance_fraction = proto.Field(proto.FLOAT, number=3)
+    confidence = proto.Field(proto.FLOAT, number=2,)
+    importance_fraction = proto.Field(proto.FLOAT, number=3,)
 
 
 class CropHintsAnnotation(proto.Message):
@@ -526,7 +485,7 @@ class CropHintsAnnotation(proto.Message):
     serving images.
 
     Attributes:
-        crop_hints (Sequence[~.image_annotator.CropHint]):
+        crop_hints (Sequence[google.cloud.vision_v1p1beta1.types.CropHint]):
             Crop hint results.
     """
 
@@ -548,7 +507,7 @@ class CropHintsParams(proto.Message):
             provided after the 16th are ignored.
     """
 
-    aspect_ratios = proto.RepeatedField(proto.FLOAT, number=1)
+    aspect_ratios = proto.RepeatedField(proto.FLOAT, number=1,)
 
 
 class WebDetectionParams(proto.Message):
@@ -560,7 +519,7 @@ class WebDetectionParams(proto.Message):
             geo information in the image.
     """
 
-    include_geo_results = proto.Field(proto.BOOL, number=2)
+    include_geo_results = proto.Field(proto.BOOL, number=2,)
 
 
 class TextDetectionParams(proto.Message):
@@ -574,14 +533,14 @@ class TextDetectionParams(proto.Message):
             include confidence score for TEXT_DETECTION as well.
     """
 
-    enable_text_detection_confidence_score = proto.Field(proto.BOOL, number=9)
+    enable_text_detection_confidence_score = proto.Field(proto.BOOL, number=9,)
 
 
 class ImageContext(proto.Message):
     r"""Image context and/or feature-specific parameters.
 
     Attributes:
-        lat_long_rect (~.image_annotator.LatLongRect):
+        lat_long_rect (google.cloud.vision_v1p1beta1.types.LatLongRect):
             lat/long rectangle that specifies the
             location of the image.
         language_hints (Sequence[str]):
@@ -595,25 +554,21 @@ class ImageContext(proto.Message):
             Text detection returns an error if one or more of the
             specified languages is not one of the `supported
             languages <https://cloud.google.com/vision/docs/languages>`__.
-        crop_hints_params (~.image_annotator.CropHintsParams):
+        crop_hints_params (google.cloud.vision_v1p1beta1.types.CropHintsParams):
             Parameters for crop hints annotation request.
-        web_detection_params (~.image_annotator.WebDetectionParams):
+        web_detection_params (google.cloud.vision_v1p1beta1.types.WebDetectionParams):
             Parameters for web detection.
-        text_detection_params (~.image_annotator.TextDetectionParams):
+        text_detection_params (google.cloud.vision_v1p1beta1.types.TextDetectionParams):
             Parameters for text detection and document
             text detection.
     """
 
     lat_long_rect = proto.Field(proto.MESSAGE, number=1, message="LatLongRect",)
-
-    language_hints = proto.RepeatedField(proto.STRING, number=2)
-
+    language_hints = proto.RepeatedField(proto.STRING, number=2,)
     crop_hints_params = proto.Field(proto.MESSAGE, number=4, message="CropHintsParams",)
-
     web_detection_params = proto.Field(
         proto.MESSAGE, number=6, message="WebDetectionParams",
     )
-
     text_detection_params = proto.Field(
         proto.MESSAGE, number=12, message="TextDetectionParams",
     )
@@ -624,19 +579,17 @@ class AnnotateImageRequest(proto.Message):
     user-provided image, with user-requested features.
 
     Attributes:
-        image (~.image_annotator.Image):
+        image (google.cloud.vision_v1p1beta1.types.Image):
             The image to be processed.
-        features (Sequence[~.image_annotator.Feature]):
+        features (Sequence[google.cloud.vision_v1p1beta1.types.Feature]):
             Requested features.
-        image_context (~.image_annotator.ImageContext):
+        image_context (google.cloud.vision_v1p1beta1.types.ImageContext):
             Additional context that may accompany the
             image.
     """
 
     image = proto.Field(proto.MESSAGE, number=1, message="Image",)
-
     features = proto.RepeatedField(proto.MESSAGE, number=2, message="Feature",)
-
     image_context = proto.Field(proto.MESSAGE, number=3, message="ImageContext",)
 
 
@@ -644,39 +597,39 @@ class AnnotateImageResponse(proto.Message):
     r"""Response to an image annotation request.
 
     Attributes:
-        face_annotations (Sequence[~.image_annotator.FaceAnnotation]):
+        face_annotations (Sequence[google.cloud.vision_v1p1beta1.types.FaceAnnotation]):
             If present, face detection has completed
             successfully.
-        landmark_annotations (Sequence[~.image_annotator.EntityAnnotation]):
+        landmark_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, landmark detection has completed
             successfully.
-        logo_annotations (Sequence[~.image_annotator.EntityAnnotation]):
+        logo_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, logo detection has completed
             successfully.
-        label_annotations (Sequence[~.image_annotator.EntityAnnotation]):
+        label_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, label detection has completed
             successfully.
-        text_annotations (Sequence[~.image_annotator.EntityAnnotation]):
+        text_annotations (Sequence[google.cloud.vision_v1p1beta1.types.EntityAnnotation]):
             If present, text (OCR) detection has
             completed successfully.
-        full_text_annotation (~.text_annotation.TextAnnotation):
+        full_text_annotation (google.cloud.vision_v1p1beta1.types.TextAnnotation):
             If present, text (OCR) detection or document
             (OCR) text detection has completed successfully.
             This annotation provides the structural
             hierarchy for the OCR detected text.
-        safe_search_annotation (~.image_annotator.SafeSearchAnnotation):
+        safe_search_annotation (google.cloud.vision_v1p1beta1.types.SafeSearchAnnotation):
             If present, safe-search annotation has
             completed successfully.
-        image_properties_annotation (~.image_annotator.ImageProperties):
+        image_properties_annotation (google.cloud.vision_v1p1beta1.types.ImageProperties):
             If present, image properties were extracted
             successfully.
-        crop_hints_annotation (~.image_annotator.CropHintsAnnotation):
+        crop_hints_annotation (google.cloud.vision_v1p1beta1.types.CropHintsAnnotation):
             If present, crop hints have completed
             successfully.
-        web_detection (~.gcv_web_detection.WebDetection):
+        web_detection (google.cloud.vision_v1p1beta1.types.WebDetection):
             If present, web detection has completed
             successfully.
-        error (~.status.Status):
+        error (google.rpc.status_pb2.Status):
             If set, represents the error message for the operation. Note
             that filled-in image annotations are guaranteed to be
             correct, even when ``error`` is set.
@@ -685,44 +638,34 @@ class AnnotateImageResponse(proto.Message):
     face_annotations = proto.RepeatedField(
         proto.MESSAGE, number=1, message="FaceAnnotation",
     )
-
     landmark_annotations = proto.RepeatedField(
         proto.MESSAGE, number=2, message="EntityAnnotation",
     )
-
     logo_annotations = proto.RepeatedField(
         proto.MESSAGE, number=3, message="EntityAnnotation",
     )
-
     label_annotations = proto.RepeatedField(
         proto.MESSAGE, number=4, message="EntityAnnotation",
     )
-
     text_annotations = proto.RepeatedField(
         proto.MESSAGE, number=5, message="EntityAnnotation",
     )
-
     full_text_annotation = proto.Field(
         proto.MESSAGE, number=12, message=text_annotation.TextAnnotation,
     )
-
     safe_search_annotation = proto.Field(
         proto.MESSAGE, number=6, message="SafeSearchAnnotation",
     )
-
     image_properties_annotation = proto.Field(
         proto.MESSAGE, number=8, message="ImageProperties",
     )
-
     crop_hints_annotation = proto.Field(
         proto.MESSAGE, number=11, message="CropHintsAnnotation",
     )
-
     web_detection = proto.Field(
         proto.MESSAGE, number=13, message=gcv_web_detection.WebDetection,
     )
-
-    error = proto.Field(proto.MESSAGE, number=9, message=status.Status,)
+    error = proto.Field(proto.MESSAGE, number=9, message=status_pb2.Status,)
 
 
 class BatchAnnotateImagesRequest(proto.Message):
@@ -730,7 +673,7 @@ class BatchAnnotateImagesRequest(proto.Message):
     service call.
 
     Attributes:
-        requests (Sequence[~.image_annotator.AnnotateImageRequest]):
+        requests (Sequence[google.cloud.vision_v1p1beta1.types.AnnotateImageRequest]):
             Required. Individual image annotation
             requests for this batch.
     """
@@ -744,7 +687,7 @@ class BatchAnnotateImagesResponse(proto.Message):
     r"""Response to a batch image annotation request.
 
     Attributes:
-        responses (Sequence[~.image_annotator.AnnotateImageResponse]):
+        responses (Sequence[google.cloud.vision_v1p1beta1.types.AnnotateImageResponse]):
             Individual responses to image annotation
             requests within the batch.
     """
