@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.vision_v1p3beta1.services.product_search import pagers
@@ -195,12 +197,12 @@ class ProductSearchAsyncClient:
 
     async def create_product_set(
         self,
-        request: product_search_service.CreateProductSetRequest = None,
+        request: Union[product_search_service.CreateProductSetRequest, dict] = None,
         *,
         parent: str = None,
         product_set: product_search_service.ProductSet = None,
         product_set_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -212,7 +214,7 @@ class ProductSearchAsyncClient:
            longer than 4096 characters.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.CreateProductSetRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.CreateProductSetRequest, dict]):
                 The request object. Request message for the
                 `CreateProductSet` method.
             parent (:class:`str`):
@@ -304,10 +306,10 @@ class ProductSearchAsyncClient:
 
     async def list_product_sets(
         self,
-        request: product_search_service.ListProductSetsRequest = None,
+        request: Union[product_search_service.ListProductSetsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductSetsAsyncPager:
@@ -319,7 +321,7 @@ class ProductSearchAsyncClient:
            less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.ListProductSetsRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.ListProductSetsRequest, dict]):
                 The request object. Request message for the
                 `ListProductSets` method.
             parent (:class:`str`):
@@ -400,10 +402,10 @@ class ProductSearchAsyncClient:
 
     async def get_product_set(
         self,
-        request: product_search_service.GetProductSetRequest = None,
+        request: Union[product_search_service.GetProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -414,7 +416,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the ProductSet does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.GetProductSetRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.GetProductSetRequest, dict]):
                 The request object. Request message for the
                 `GetProductSet` method.
             name (:class:`str`):
@@ -490,11 +492,11 @@ class ProductSearchAsyncClient:
 
     async def update_product_set(
         self,
-        request: product_search_service.UpdateProductSetRequest = None,
+        request: Union[product_search_service.UpdateProductSetRequest, dict] = None,
         *,
         product_set: product_search_service.ProductSet = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -509,7 +511,7 @@ class ProductSearchAsyncClient:
            characters.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.UpdateProductSetRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.UpdateProductSetRequest, dict]):
                 The request object. Request message for the
                 `UpdateProductSet` method.
             product_set (:class:`google.cloud.vision_v1p3beta1.types.ProductSet`):
@@ -593,10 +595,10 @@ class ProductSearchAsyncClient:
 
     async def delete_product_set(
         self,
-        request: product_search_service.DeleteProductSetRequest = None,
+        request: Union[product_search_service.DeleteProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -611,7 +613,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the ProductSet does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.DeleteProductSetRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.DeleteProductSetRequest, dict]):
                 The request object. Request message for the
                 `DeleteProductSet` method.
             name (:class:`str`):
@@ -677,12 +679,12 @@ class ProductSearchAsyncClient:
 
     async def create_product(
         self,
-        request: product_search_service.CreateProductRequest = None,
+        request: Union[product_search_service.CreateProductRequest, dict] = None,
         *,
         parent: str = None,
         product: product_search_service.Product = None,
         product_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -698,7 +700,7 @@ class ProductSearchAsyncClient:
            invalid.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.CreateProductRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.CreateProductRequest, dict]):
                 The request object. Request message for the
                 `CreateProduct` method.
             parent (:class:`str`):
@@ -785,10 +787,10 @@ class ProductSearchAsyncClient:
 
     async def list_products(
         self,
-        request: product_search_service.ListProductsRequest = None,
+        request: Union[product_search_service.ListProductsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsAsyncPager:
@@ -800,7 +802,7 @@ class ProductSearchAsyncClient:
            less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.ListProductsRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.ListProductsRequest, dict]):
                 The request object. Request message for the
                 `ListProducts` method.
             parent (:class:`str`):
@@ -881,10 +883,10 @@ class ProductSearchAsyncClient:
 
     async def get_product(
         self,
-        request: product_search_service.GetProductRequest = None,
+        request: Union[product_search_service.GetProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -895,7 +897,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the Product does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.GetProductRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.GetProductRequest, dict]):
                 The request object. Request message for the `GetProduct`
                 method.
             name (:class:`str`):
@@ -966,11 +968,11 @@ class ProductSearchAsyncClient:
 
     async def update_product(
         self,
-        request: product_search_service.UpdateProductRequest = None,
+        request: Union[product_search_service.UpdateProductRequest, dict] = None,
         *,
         product: product_search_service.Product = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -992,7 +994,7 @@ class ProductSearchAsyncClient:
            update_mask.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.UpdateProductRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.UpdateProductRequest, dict]):
                 The request object. Request message for the
                 `UpdateProduct` method.
             product (:class:`google.cloud.vision_v1p3beta1.types.Product`):
@@ -1073,10 +1075,10 @@ class ProductSearchAsyncClient:
 
     async def delete_product(
         self,
-        request: product_search_service.DeleteProductRequest = None,
+        request: Union[product_search_service.DeleteProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1091,7 +1093,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the product does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.DeleteProductRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.DeleteProductRequest, dict]):
                 The request object. Request message for the
                 `DeleteProduct` method.
             name (:class:`str`):
@@ -1157,12 +1159,12 @@ class ProductSearchAsyncClient:
 
     async def create_reference_image(
         self,
-        request: product_search_service.CreateReferenceImageRequest = None,
+        request: Union[product_search_service.CreateReferenceImageRequest, dict] = None,
         *,
         parent: str = None,
         reference_image: product_search_service.ReferenceImage = None,
         reference_image_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1190,7 +1192,7 @@ class ProductSearchAsyncClient:
            10 polygons.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.CreateReferenceImageRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.CreateReferenceImageRequest, dict]):
                 The request object. Request message for the
                 `CreateReferenceImage` method.
             parent (:class:`str`):
@@ -1283,10 +1285,10 @@ class ProductSearchAsyncClient:
 
     async def delete_reference_image(
         self,
-        request: product_search_service.DeleteReferenceImageRequest = None,
+        request: Union[product_search_service.DeleteReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1304,7 +1306,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the reference image does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.DeleteReferenceImageRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.DeleteReferenceImageRequest, dict]):
                 The request object. Request message for the
                 `DeleteReferenceImage` method.
             name (:class:`str`):
@@ -1372,10 +1374,10 @@ class ProductSearchAsyncClient:
 
     async def list_reference_images(
         self,
-        request: product_search_service.ListReferenceImagesRequest = None,
+        request: Union[product_search_service.ListReferenceImagesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReferenceImagesAsyncPager:
@@ -1388,7 +1390,7 @@ class ProductSearchAsyncClient:
            100, or less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.ListReferenceImagesRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.ListReferenceImagesRequest, dict]):
                 The request object. Request message for the
                 `ListReferenceImages` method.
             parent (:class:`str`):
@@ -1470,10 +1472,10 @@ class ProductSearchAsyncClient:
 
     async def get_reference_image(
         self,
-        request: product_search_service.GetReferenceImageRequest = None,
+        request: Union[product_search_service.GetReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1484,7 +1486,7 @@ class ProductSearchAsyncClient:
         -  Returns NOT_FOUND if the specified image does not exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.GetReferenceImageRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.GetReferenceImageRequest, dict]):
                 The request object. Request message for the
                 `GetReferenceImage` method.
             name (:class:`str`):
@@ -1559,11 +1561,13 @@ class ProductSearchAsyncClient:
 
     async def add_product_to_product_set(
         self,
-        request: product_search_service.AddProductToProductSetRequest = None,
+        request: Union[
+            product_search_service.AddProductToProductSetRequest, dict
+        ] = None,
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1578,7 +1582,7 @@ class ProductSearchAsyncClient:
            exist.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.AddProductToProductSetRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.AddProductToProductSetRequest, dict]):
                 The request object. Request message for the
                 `AddProductToProductSet` method.
             name (:class:`str`):
@@ -1654,11 +1658,13 @@ class ProductSearchAsyncClient:
 
     async def remove_product_from_product_set(
         self,
-        request: product_search_service.RemoveProductFromProductSetRequest = None,
+        request: Union[
+            product_search_service.RemoveProductFromProductSetRequest, dict
+        ] = None,
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1670,7 +1676,7 @@ class ProductSearchAsyncClient:
            ProductSet.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.RemoveProductFromProductSetRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.RemoveProductFromProductSetRequest, dict]):
                 The request object. Request message for the
                 `RemoveProductFromProductSet` method.
             name (:class:`str`):
@@ -1746,10 +1752,12 @@ class ProductSearchAsyncClient:
 
     async def list_products_in_product_set(
         self,
-        request: product_search_service.ListProductsInProductSetRequest = None,
+        request: Union[
+            product_search_service.ListProductsInProductSetRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsInProductSetAsyncPager:
@@ -1763,7 +1771,7 @@ class ProductSearchAsyncClient:
            less than 1.
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.ListProductsInProductSetRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.ListProductsInProductSetRequest, dict]):
                 The request object. Request message for the
                 `ListProductsInProductSet` method.
             name (:class:`str`):
@@ -1846,11 +1854,11 @@ class ProductSearchAsyncClient:
 
     async def import_product_sets(
         self,
-        request: product_search_service.ImportProductSetsRequest = None,
+        request: Union[product_search_service.ImportProductSetsRequest, dict] = None,
         *,
         parent: str = None,
         input_config: product_search_service.ImportProductSetsInputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1868,7 +1876,7 @@ class ProductSearchAsyncClient:
         [ImportProductSetsGcsSource.csv_file_uri][google.cloud.vision.v1p3beta1.ImportProductSetsGcsSource.csv_file_uri].
 
         Args:
-            request (:class:`google.cloud.vision_v1p3beta1.types.ImportProductSetsRequest`):
+            request (Union[google.cloud.vision_v1p3beta1.types.ImportProductSetsRequest, dict]):
                 The request object. Request message for the
                 `ImportProductSets` method.
             parent (:class:`str`):
