@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.vision_v1p3beta1.services.product_search import pagers
@@ -415,7 +417,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         parent: str = None,
         product_set: product_search_service.ProductSet = None,
         product_set_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -515,7 +517,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.ListProductSetsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductSetsPager:
@@ -601,7 +603,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.GetProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -682,7 +684,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         product_set: product_search_service.ProductSet = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ProductSet:
@@ -777,7 +779,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.DeleteProductSetRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -853,7 +855,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         parent: str = None,
         product: product_search_service.Product = None,
         product_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -952,7 +954,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.ListProductsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsPager:
@@ -1038,7 +1040,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.GetProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -1114,7 +1116,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         product: product_search_service.Product = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.Product:
@@ -1213,7 +1215,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.DeleteProductRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1289,7 +1291,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         parent: str = None,
         reference_image: product_search_service.ReferenceImage = None,
         reference_image_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1406,7 +1408,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.DeleteReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1485,7 +1487,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.ListReferenceImagesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReferenceImagesPager:
@@ -1573,7 +1575,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         request: Union[product_search_service.GetReferenceImageRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> product_search_service.ReferenceImage:
@@ -1655,7 +1657,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1749,7 +1751,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         name: str = None,
         product: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1839,7 +1841,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListProductsInProductSetPager:
@@ -1934,7 +1936,7 @@ class ProductSearchClient(metaclass=ProductSearchClientMeta):
         *,
         parent: str = None,
         input_config: product_search_service.ImportProductSetsInputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
